#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# flake8: noqa

# import apis into api package
from polyaxon_sdk.api.agents_v1_api import AgentsV1Api
from polyaxon_sdk.api.artifacts_stores_v1_api import ArtifactsStoresV1Api
from polyaxon_sdk.api.auth_v1_api import AuthV1Api
from polyaxon_sdk.api.connections_v1_api import ConnectionsV1Api
from polyaxon_sdk.api.dashboards_v1_api import DashboardsV1Api
from polyaxon_sdk.api.organizations_v1_api import OrganizationsV1Api
from polyaxon_sdk.api.presets_v1_api import PresetsV1Api
from polyaxon_sdk.api.project_dashboards_v1_api import ProjectDashboardsV1Api
from polyaxon_sdk.api.project_searches_v1_api import ProjectSearchesV1Api
from polyaxon_sdk.api.projects_v1_api import ProjectsV1Api
from polyaxon_sdk.api.queues_v1_api import QueuesV1Api
from polyaxon_sdk.api.runs_v1_api import RunsV1Api
from polyaxon_sdk.api.schemas_v1_api import SchemasV1Api
from polyaxon_sdk.api.searches_v1_api import SearchesV1Api
from polyaxon_sdk.api.service_accounts_v1_api import ServiceAccountsV1Api
from polyaxon_sdk.api.tags_v1_api import TagsV1Api
from polyaxon_sdk.api.teams_v1_api import TeamsV1Api
from polyaxon_sdk.api.users_v1_api import UsersV1Api
from polyaxon_sdk.api.versions_v1_api import VersionsV1Api




#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc5
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from polyaxon_sdk.models.v1_artifacts_mount import V1ArtifactsMount
from polyaxon_sdk.models.v1_artifacts_type import V1ArtifactsType
from polyaxon_sdk.models.v1_auth_type import V1AuthType
from polyaxon_sdk.models.v1_compiled_operation import V1CompiledOperation
from polyaxon_sdk.models.v1_connection_schema import V1ConnectionSchema
from polyaxon_sdk.models.v1_connection_type import V1ConnectionType
from polyaxon_sdk.models.v1_early_stopping import V1EarlyStopping
from polyaxon_sdk.models.v1_event import V1Event
from polyaxon_sdk.models.v1_event_type import V1EventType
from polyaxon_sdk.models.v1_gcs_type import V1GcsType
from polyaxon_sdk.models.v1_hp_params import V1HpParams
from polyaxon_sdk.models.v1_k8s_resource_type import V1K8sResourceType
from polyaxon_sdk.models.v1_matrix import V1Matrix
from polyaxon_sdk.models.v1_matrix_kind import V1MatrixKind
from polyaxon_sdk.models.v1_operation import V1Operation
from polyaxon_sdk.models.v1_polyaxon_init_container import V1PolyaxonInitContainer
from polyaxon_sdk.models.v1_polyaxon_sidecar_container import V1PolyaxonSidecarContainer
from polyaxon_sdk.models.v1_reference import V1Reference
from polyaxon_sdk.models.v1_run_schema import V1RunSchema
from polyaxon_sdk.models.v1_s3_type import V1S3Type
from polyaxon_sdk.models.v1_schedule import V1Schedule
from polyaxon_sdk.models.v1_schedule_kind import V1ScheduleKind
from polyaxon_sdk.models.v1_uri_type import V1UriType
from polyaxon_sdk.models.v1_wasb_type import V1WasbType

class V1Schemas(BaseModel):
    """
    V1Schemas
    """
    early_stopping: Optional[V1EarlyStopping] = Field(None, alias="earlyStopping")
    matrix: Optional[V1Matrix] = None
    run: Optional[V1RunSchema] = None
    operation: Optional[V1Operation] = None
    compiled_operation: Optional[V1CompiledOperation] = Field(None, alias="compiledOperation")
    schedule: Optional[V1Schedule] = None
    connection_schema: Optional[V1ConnectionSchema] = Field(None, alias="connectionSchema")
    hp_params: Optional[V1HpParams] = Field(None, alias="hpParams")
    reference: Optional[V1Reference] = None
    artifacts_mount: Optional[V1ArtifactsMount] = Field(None, alias="artifactsMount")
    polyaxon_sidecar_container: Optional[V1PolyaxonSidecarContainer] = Field(None, alias="polyaxonSidecarContainer")
    polyaxon_init_container: Optional[V1PolyaxonInitContainer] = Field(None, alias="polyaxonInitContainer")
    artifacs: Optional[V1ArtifactsType] = None
    wasb: Optional[V1WasbType] = None
    gcs: Optional[V1GcsType] = None
    s3: Optional[V1S3Type] = None
    auth: Optional[V1AuthType] = None
    uri: Optional[V1UriType] = None
    k8s_resource: Optional[V1K8sResourceType] = Field(None, alias="k8sResource")
    connection: Optional[V1ConnectionType] = None
    event_type: Optional[V1EventType] = Field(None, alias="eventType")
    matrix_kind: Optional[V1MatrixKind] = Field(None, alias="matrixKind")
    schedule_kind: Optional[V1ScheduleKind] = Field(None, alias="scheduleKind")
    event: Optional[V1Event] = None
    __properties = ["earlyStopping", "matrix", "run", "operation", "compiledOperation", "schedule", "connectionSchema", "hpParams", "reference", "artifactsMount", "polyaxonSidecarContainer", "polyaxonInitContainer", "artifacs", "wasb", "gcs", "s3", "auth", "uri", "k8sResource", "connection", "eventType", "matrixKind", "scheduleKind", "event"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Schemas:
        """Create an instance of V1Schemas from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of early_stopping
        if self.early_stopping:
            _dict['earlyStopping'] = self.early_stopping.to_dict()
        # override the default output from pydantic by calling `to_dict()` of matrix
        if self.matrix:
            _dict['matrix'] = self.matrix.to_dict()
        # override the default output from pydantic by calling `to_dict()` of run
        if self.run:
            _dict['run'] = self.run.to_dict()
        # override the default output from pydantic by calling `to_dict()` of operation
        if self.operation:
            _dict['operation'] = self.operation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of compiled_operation
        if self.compiled_operation:
            _dict['compiledOperation'] = self.compiled_operation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of schedule
        if self.schedule:
            _dict['schedule'] = self.schedule.to_dict()
        # override the default output from pydantic by calling `to_dict()` of connection_schema
        if self.connection_schema:
            _dict['connectionSchema'] = self.connection_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hp_params
        if self.hp_params:
            _dict['hpParams'] = self.hp_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of reference
        if self.reference:
            _dict['reference'] = self.reference.to_dict()
        # override the default output from pydantic by calling `to_dict()` of artifacts_mount
        if self.artifacts_mount:
            _dict['artifactsMount'] = self.artifacts_mount.to_dict()
        # override the default output from pydantic by calling `to_dict()` of polyaxon_sidecar_container
        if self.polyaxon_sidecar_container:
            _dict['polyaxonSidecarContainer'] = self.polyaxon_sidecar_container.to_dict()
        # override the default output from pydantic by calling `to_dict()` of polyaxon_init_container
        if self.polyaxon_init_container:
            _dict['polyaxonInitContainer'] = self.polyaxon_init_container.to_dict()
        # override the default output from pydantic by calling `to_dict()` of artifacs
        if self.artifacs:
            _dict['artifacs'] = self.artifacs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of wasb
        if self.wasb:
            _dict['wasb'] = self.wasb.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gcs
        if self.gcs:
            _dict['gcs'] = self.gcs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of s3
        if self.s3:
            _dict['s3'] = self.s3.to_dict()
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict['auth'] = self.auth.to_dict()
        # override the default output from pydantic by calling `to_dict()` of uri
        if self.uri:
            _dict['uri'] = self.uri.to_dict()
        # override the default output from pydantic by calling `to_dict()` of k8s_resource
        if self.k8s_resource:
            _dict['k8sResource'] = self.k8s_resource.to_dict()
        # override the default output from pydantic by calling `to_dict()` of connection
        if self.connection:
            _dict['connection'] = self.connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of event_type
        if self.event_type:
            _dict['eventType'] = self.event_type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of event
        if self.event:
            _dict['event'] = self.event.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Schemas:
        """Create an instance of V1Schemas from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Schemas.parse_obj(obj)

        _obj = V1Schemas.parse_obj({
            "early_stopping": V1EarlyStopping.from_dict(obj.get("earlyStopping")) if obj.get("earlyStopping") is not None else None,
            "matrix": V1Matrix.from_dict(obj.get("matrix")) if obj.get("matrix") is not None else None,
            "run": V1RunSchema.from_dict(obj.get("run")) if obj.get("run") is not None else None,
            "operation": V1Operation.from_dict(obj.get("operation")) if obj.get("operation") is not None else None,
            "compiled_operation": V1CompiledOperation.from_dict(obj.get("compiledOperation")) if obj.get("compiledOperation") is not None else None,
            "schedule": V1Schedule.from_dict(obj.get("schedule")) if obj.get("schedule") is not None else None,
            "connection_schema": V1ConnectionSchema.from_dict(obj.get("connectionSchema")) if obj.get("connectionSchema") is not None else None,
            "hp_params": V1HpParams.from_dict(obj.get("hpParams")) if obj.get("hpParams") is not None else None,
            "reference": V1Reference.from_dict(obj.get("reference")) if obj.get("reference") is not None else None,
            "artifacts_mount": V1ArtifactsMount.from_dict(obj.get("artifactsMount")) if obj.get("artifactsMount") is not None else None,
            "polyaxon_sidecar_container": V1PolyaxonSidecarContainer.from_dict(obj.get("polyaxonSidecarContainer")) if obj.get("polyaxonSidecarContainer") is not None else None,
            "polyaxon_init_container": V1PolyaxonInitContainer.from_dict(obj.get("polyaxonInitContainer")) if obj.get("polyaxonInitContainer") is not None else None,
            "artifacs": V1ArtifactsType.from_dict(obj.get("artifacs")) if obj.get("artifacs") is not None else None,
            "wasb": V1WasbType.from_dict(obj.get("wasb")) if obj.get("wasb") is not None else None,
            "gcs": V1GcsType.from_dict(obj.get("gcs")) if obj.get("gcs") is not None else None,
            "s3": V1S3Type.from_dict(obj.get("s3")) if obj.get("s3") is not None else None,
            "auth": V1AuthType.from_dict(obj.get("auth")) if obj.get("auth") is not None else None,
            "uri": V1UriType.from_dict(obj.get("uri")) if obj.get("uri") is not None else None,
            "k8s_resource": V1K8sResourceType.from_dict(obj.get("k8sResource")) if obj.get("k8sResource") is not None else None,
            "connection": V1ConnectionType.from_dict(obj.get("connection")) if obj.get("connection") is not None else None,
            "event_type": V1EventType.from_dict(obj.get("eventType")) if obj.get("eventType") is not None else None,
            "matrix_kind": obj.get("matrixKind"),
            "schedule_kind": obj.get("scheduleKind"),
            "event": V1Event.from_dict(obj.get("event")) if obj.get("event") is not None else None
        })
        return _obj




#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

# flake8: noqa
"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc5
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from polyaxon_sdk.models.agent_state_response_agent_state import AgentStateResponseAgentState
from polyaxon_sdk.models.mx_job_mode import MXJobMode
from polyaxon_sdk.models.protobuf_any import ProtobufAny
from polyaxon_sdk.models.protobuf_null_value import ProtobufNullValue
from polyaxon_sdk.models.runtime_error import RuntimeError
from polyaxon_sdk.models.search_view import SearchView
from polyaxon_sdk.models.spark_deploy_mode import SparkDeployMode
from polyaxon_sdk.models.v1_activity import V1Activity
from polyaxon_sdk.models.v1_agent import V1Agent
from polyaxon_sdk.models.v1_agent_state_response import V1AgentStateResponse
from polyaxon_sdk.models.v1_agent_status_body_request import V1AgentStatusBodyRequest
from polyaxon_sdk.models.v1_analytics_spec import V1AnalyticsSpec
from polyaxon_sdk.models.v1_artifact_kind import V1ArtifactKind
from polyaxon_sdk.models.v1_artifact_tree import V1ArtifactTree
from polyaxon_sdk.models.v1_artifacts_mount import V1ArtifactsMount
from polyaxon_sdk.models.v1_artifacts_type import V1ArtifactsType
from polyaxon_sdk.models.v1_auth import V1Auth
from polyaxon_sdk.models.v1_auth_type import V1AuthType
from polyaxon_sdk.models.v1_average_stopping_policy import V1AverageStoppingPolicy
from polyaxon_sdk.models.v1_bayes import V1Bayes
from polyaxon_sdk.models.v1_bucket_connection import V1BucketConnection
from polyaxon_sdk.models.v1_build import V1Build
from polyaxon_sdk.models.v1_cache import V1Cache
from polyaxon_sdk.models.v1_claim_connection import V1ClaimConnection
from polyaxon_sdk.models.v1_clean_pod_policy import V1CleanPodPolicy
from polyaxon_sdk.models.v1_cloning import V1Cloning
from polyaxon_sdk.models.v1_cloning_kind import V1CloningKind
from polyaxon_sdk.models.v1_compatibility import V1Compatibility
from polyaxon_sdk.models.v1_compiled_operation import V1CompiledOperation
from polyaxon_sdk.models.v1_component import V1Component
from polyaxon_sdk.models.v1_connection_kind import V1ConnectionKind
from polyaxon_sdk.models.v1_connection_response import V1ConnectionResponse
from polyaxon_sdk.models.v1_connection_schema import V1ConnectionSchema
from polyaxon_sdk.models.v1_connection_type import V1ConnectionType
from polyaxon_sdk.models.v1_credentials import V1Credentials
from polyaxon_sdk.models.v1_cron_schedule import V1CronSchedule
from polyaxon_sdk.models.v1_dag import V1Dag
from polyaxon_sdk.models.v1_dag_ref import V1DagRef
from polyaxon_sdk.models.v1_dashboard import V1Dashboard
from polyaxon_sdk.models.v1_dashboard_spec import V1DashboardSpec
from polyaxon_sdk.models.v1_dask import V1Dask
from polyaxon_sdk.models.v1_date_time_schedule import V1DateTimeSchedule
from polyaxon_sdk.models.v1_diff_stopping_policy import V1DiffStoppingPolicy
from polyaxon_sdk.models.v1_dockerfile_type import V1DockerfileType
from polyaxon_sdk.models.v1_early_stopping import V1EarlyStopping
from polyaxon_sdk.models.v1_entities_tags import V1EntitiesTags
from polyaxon_sdk.models.v1_entities_transfer import V1EntitiesTransfer
from polyaxon_sdk.models.v1_entity_notification_body import V1EntityNotificationBody
from polyaxon_sdk.models.v1_entity_stage_body_request import V1EntityStageBodyRequest
from polyaxon_sdk.models.v1_entity_status_body_request import V1EntityStatusBodyRequest
from polyaxon_sdk.models.v1_environment import V1Environment
from polyaxon_sdk.models.v1_event import V1Event
from polyaxon_sdk.models.v1_event_artifact import V1EventArtifact
from polyaxon_sdk.models.v1_event_audio import V1EventAudio
from polyaxon_sdk.models.v1_event_chart import V1EventChart
from polyaxon_sdk.models.v1_event_chart_kind import V1EventChartKind
from polyaxon_sdk.models.v1_event_confusion_matrix import V1EventConfusionMatrix
from polyaxon_sdk.models.v1_event_curve import V1EventCurve
from polyaxon_sdk.models.v1_event_curve_kind import V1EventCurveKind
from polyaxon_sdk.models.v1_event_dataframe import V1EventDataframe
from polyaxon_sdk.models.v1_event_histogram import V1EventHistogram
from polyaxon_sdk.models.v1_event_image import V1EventImage
from polyaxon_sdk.models.v1_event_kind import V1EventKind
from polyaxon_sdk.models.v1_event_model import V1EventModel
from polyaxon_sdk.models.v1_event_trigger import V1EventTrigger
from polyaxon_sdk.models.v1_event_type import V1EventType
from polyaxon_sdk.models.v1_event_video import V1EventVideo
from polyaxon_sdk.models.v1_events_response import V1EventsResponse
from polyaxon_sdk.models.v1_failure_early_stopping import V1FailureEarlyStopping
from polyaxon_sdk.models.v1_file_type import V1FileType
from polyaxon_sdk.models.v1_flink import V1Flink
from polyaxon_sdk.models.v1_gcs_type import V1GcsType
from polyaxon_sdk.models.v1_git_connection import V1GitConnection
from polyaxon_sdk.models.v1_git_type import V1GitType
from polyaxon_sdk.models.v1_grid_search import V1GridSearch
from polyaxon_sdk.models.v1_hook import V1Hook
from polyaxon_sdk.models.v1_host_connection import V1HostConnection
from polyaxon_sdk.models.v1_host_path_connection import V1HostPathConnection
from polyaxon_sdk.models.v1_hp_choice import V1HpChoice
from polyaxon_sdk.models.v1_hp_date_range import V1HpDateRange
from polyaxon_sdk.models.v1_hp_date_time_range import V1HpDateTimeRange
from polyaxon_sdk.models.v1_hp_geom_space import V1HpGeomSpace
from polyaxon_sdk.models.v1_hp_lin_space import V1HpLinSpace
from polyaxon_sdk.models.v1_hp_log_normal import V1HpLogNormal
from polyaxon_sdk.models.v1_hp_log_space import V1HpLogSpace
from polyaxon_sdk.models.v1_hp_log_uniform import V1HpLogUniform
from polyaxon_sdk.models.v1_hp_normal import V1HpNormal
from polyaxon_sdk.models.v1_hp_p_choice import V1HpPChoice
from polyaxon_sdk.models.v1_hp_params import V1HpParams
from polyaxon_sdk.models.v1_hp_q_log_normal import V1HpQLogNormal
from polyaxon_sdk.models.v1_hp_q_log_uniform import V1HpQLogUniform
from polyaxon_sdk.models.v1_hp_q_normal import V1HpQNormal
from polyaxon_sdk.models.v1_hp_q_uniform import V1HpQUniform
from polyaxon_sdk.models.v1_hp_range import V1HpRange
from polyaxon_sdk.models.v1_hp_uniform import V1HpUniform
from polyaxon_sdk.models.v1_hub_ref import V1HubRef
from polyaxon_sdk.models.v1_hyperband import V1Hyperband
from polyaxon_sdk.models.v1_hyperopt import V1Hyperopt
from polyaxon_sdk.models.v1_hyperopt_algorithms import V1HyperoptAlgorithms
from polyaxon_sdk.models.v1_io import V1IO
from polyaxon_sdk.models.v1_init import V1Init
from polyaxon_sdk.models.v1_installation import V1Installation
from polyaxon_sdk.models.v1_interval_schedule import V1IntervalSchedule
from polyaxon_sdk.models.v1_iterative import V1Iterative
from polyaxon_sdk.models.v1_job import V1Job
from polyaxon_sdk.models.v1_join import V1Join
from polyaxon_sdk.models.v1_join_param import V1JoinParam
from polyaxon_sdk.models.v1_k8s_resource_schema import V1K8sResourceSchema
from polyaxon_sdk.models.v1_k8s_resource_type import V1K8sResourceType
from polyaxon_sdk.models.v1_kf_replica import V1KFReplica
from polyaxon_sdk.models.v1_list_activities_response import V1ListActivitiesResponse
from polyaxon_sdk.models.v1_list_agents_response import V1ListAgentsResponse
from polyaxon_sdk.models.v1_list_bookmarks_response import V1ListBookmarksResponse
from polyaxon_sdk.models.v1_list_connections_response import V1ListConnectionsResponse
from polyaxon_sdk.models.v1_list_dashboards_response import V1ListDashboardsResponse
from polyaxon_sdk.models.v1_list_organization_members_response import V1ListOrganizationMembersResponse
from polyaxon_sdk.models.v1_list_organizations_response import V1ListOrganizationsResponse
from polyaxon_sdk.models.v1_list_presets_response import V1ListPresetsResponse
from polyaxon_sdk.models.v1_list_project_versions_response import V1ListProjectVersionsResponse
from polyaxon_sdk.models.v1_list_projects_response import V1ListProjectsResponse
from polyaxon_sdk.models.v1_list_queues_response import V1ListQueuesResponse
from polyaxon_sdk.models.v1_list_run_artifacts_response import V1ListRunArtifactsResponse
from polyaxon_sdk.models.v1_list_run_connections_response import V1ListRunConnectionsResponse
from polyaxon_sdk.models.v1_list_run_edges_response import V1ListRunEdgesResponse
from polyaxon_sdk.models.v1_list_runs_response import V1ListRunsResponse
from polyaxon_sdk.models.v1_list_searches_response import V1ListSearchesResponse
from polyaxon_sdk.models.v1_list_service_accounts_response import V1ListServiceAccountsResponse
from polyaxon_sdk.models.v1_list_tags_response import V1ListTagsResponse
from polyaxon_sdk.models.v1_list_team_members_response import V1ListTeamMembersResponse
from polyaxon_sdk.models.v1_list_teams_response import V1ListTeamsResponse
from polyaxon_sdk.models.v1_list_token_response import V1ListTokenResponse
from polyaxon_sdk.models.v1_log import V1Log
from polyaxon_sdk.models.v1_log_handler import V1LogHandler
from polyaxon_sdk.models.v1_logs import V1Logs
from polyaxon_sdk.models.v1_mpi_job import V1MPIJob
from polyaxon_sdk.models.v1_mx_job import V1MXJob
from polyaxon_sdk.models.v1_mapping import V1Mapping
from polyaxon_sdk.models.v1_matrix import V1Matrix
from polyaxon_sdk.models.v1_matrix_kind import V1MatrixKind
from polyaxon_sdk.models.v1_median_stopping_policy import V1MedianStoppingPolicy
from polyaxon_sdk.models.v1_metric_early_stopping import V1MetricEarlyStopping
from polyaxon_sdk.models.v1_notification import V1Notification
from polyaxon_sdk.models.v1_operation import V1Operation
from polyaxon_sdk.models.v1_operation_body import V1OperationBody
from polyaxon_sdk.models.v1_optimization import V1Optimization
from polyaxon_sdk.models.v1_optimization_metric import V1OptimizationMetric
from polyaxon_sdk.models.v1_optimization_resource import V1OptimizationResource
from polyaxon_sdk.models.v1_organization import V1Organization
from polyaxon_sdk.models.v1_organization_member import V1OrganizationMember
from polyaxon_sdk.models.v1_paddle_job import V1PaddleJob
from polyaxon_sdk.models.v1_param import V1Param
from polyaxon_sdk.models.v1_password_change import V1PasswordChange
from polyaxon_sdk.models.v1_patch_strategy import V1PatchStrategy
from polyaxon_sdk.models.v1_path_ref import V1PathRef
from polyaxon_sdk.models.v1_pipeline import V1Pipeline
from polyaxon_sdk.models.v1_pipeline_kind import V1PipelineKind
from polyaxon_sdk.models.v1_plugins import V1Plugins
from polyaxon_sdk.models.v1_polyaxon_init_container import V1PolyaxonInitContainer
from polyaxon_sdk.models.v1_polyaxon_sidecar_container import V1PolyaxonSidecarContainer
from polyaxon_sdk.models.v1_preset import V1Preset
from polyaxon_sdk.models.v1_project import V1Project
from polyaxon_sdk.models.v1_project_settings import V1ProjectSettings
from polyaxon_sdk.models.v1_project_user_access import V1ProjectUserAccess
from polyaxon_sdk.models.v1_project_version import V1ProjectVersion
from polyaxon_sdk.models.v1_project_version_kind import V1ProjectVersionKind
from polyaxon_sdk.models.v1_pytorch_job import V1PytorchJob
from polyaxon_sdk.models.v1_queue import V1Queue
from polyaxon_sdk.models.v1_random_search import V1RandomSearch
from polyaxon_sdk.models.v1_ray import V1Ray
from polyaxon_sdk.models.v1_reference import V1Reference
from polyaxon_sdk.models.v1_resource_type import V1ResourceType
from polyaxon_sdk.models.v1_run import V1Run
from polyaxon_sdk.models.v1_run_artifact import V1RunArtifact
from polyaxon_sdk.models.v1_run_artifacts import V1RunArtifacts
from polyaxon_sdk.models.v1_run_connection import V1RunConnection
from polyaxon_sdk.models.v1_run_edge import V1RunEdge
from polyaxon_sdk.models.v1_run_edge_kind import V1RunEdgeKind
from polyaxon_sdk.models.v1_run_kind import V1RunKind
from polyaxon_sdk.models.v1_run_pending import V1RunPending
from polyaxon_sdk.models.v1_run_reference_catalog import V1RunReferenceCatalog
from polyaxon_sdk.models.v1_run_resources import V1RunResources
from polyaxon_sdk.models.v1_run_schema import V1RunSchema
from polyaxon_sdk.models.v1_run_settings import V1RunSettings
from polyaxon_sdk.models.v1_s3_type import V1S3Type
from polyaxon_sdk.models.v1_schedule import V1Schedule
from polyaxon_sdk.models.v1_schedule_kind import V1ScheduleKind
from polyaxon_sdk.models.v1_scheduling_policy import V1SchedulingPolicy
from polyaxon_sdk.models.v1_schemas import V1Schemas
from polyaxon_sdk.models.v1_search import V1Search
from polyaxon_sdk.models.v1_search_spec import V1SearchSpec
from polyaxon_sdk.models.v1_section_spec import V1SectionSpec
from polyaxon_sdk.models.v1_service import V1Service
from polyaxon_sdk.models.v1_service_account import V1ServiceAccount
from polyaxon_sdk.models.v1_settings_catalog import V1SettingsCatalog
from polyaxon_sdk.models.v1_spark import V1Spark
from polyaxon_sdk.models.v1_spark_replica import V1SparkReplica
from polyaxon_sdk.models.v1_spark_type import V1SparkType
from polyaxon_sdk.models.v1_stage import V1Stage
from polyaxon_sdk.models.v1_stage_condition import V1StageCondition
from polyaxon_sdk.models.v1_stages import V1Stages
from polyaxon_sdk.models.v1_status import V1Status
from polyaxon_sdk.models.v1_status_condition import V1StatusCondition
from polyaxon_sdk.models.v1_statuses import V1Statuses
from polyaxon_sdk.models.v1_tf_job import V1TFJob
from polyaxon_sdk.models.v1_tag import V1Tag
from polyaxon_sdk.models.v1_team import V1Team
from polyaxon_sdk.models.v1_team_member import V1TeamMember
from polyaxon_sdk.models.v1_team_settings import V1TeamSettings
from polyaxon_sdk.models.v1_template import V1Template
from polyaxon_sdk.models.v1_tensorboard_type import V1TensorboardType
from polyaxon_sdk.models.v1_termination import V1Termination
from polyaxon_sdk.models.v1_token import V1Token
from polyaxon_sdk.models.v1_trial_start import V1TrialStart
from polyaxon_sdk.models.v1_trigger_policy import V1TriggerPolicy
from polyaxon_sdk.models.v1_truncation_stopping_policy import V1TruncationStoppingPolicy
from polyaxon_sdk.models.v1_tuner import V1Tuner
from polyaxon_sdk.models.v1_uri_type import V1UriType
from polyaxon_sdk.models.v1_url_ref import V1UrlRef
from polyaxon_sdk.models.v1_user import V1User
from polyaxon_sdk.models.v1_user_email import V1UserEmail
from polyaxon_sdk.models.v1_user_singup import V1UserSingup
from polyaxon_sdk.models.v1_uuids import V1Uuids
from polyaxon_sdk.models.v1_version import V1Version
from polyaxon_sdk.models.v1_wasb_type import V1WasbType
from polyaxon_sdk.models.v1_xg_boost_job import V1XGBoostJob



#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc5
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from polyaxon_sdk.models.v1_project_version_kind import V1ProjectVersionKind
from polyaxon_sdk.models.v1_stage_condition import V1StageCondition
from polyaxon_sdk.models.v1_stages import V1Stages

class V1ProjectVersion(BaseModel):
    """
    V1ProjectVersion
    """
    uuid: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    tags: Optional[conlist(StrictStr)] = None
    owner: Optional[StrictStr] = None
    project: Optional[StrictStr] = None
    connection: Optional[StrictStr] = None
    run: Optional[StrictStr] = None
    artifacts: Optional[conlist(StrictStr)] = None
    meta_info: Optional[Dict[str, Any]] = Field(None, description="Extra information related to the run, lineage, artifacts, ...")
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    stage: Optional[V1Stages] = None
    kind: Optional[V1ProjectVersionKind] = None
    stage_conditions: Optional[conlist(V1StageCondition)] = None
    content: Optional[StrictStr] = None
    readme: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    role: Optional[StrictStr] = None
    __properties = ["uuid", "name", "description", "tags", "owner", "project", "connection", "run", "artifacts", "meta_info", "created_at", "updated_at", "stage", "kind", "stage_conditions", "content", "readme", "state", "role"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ProjectVersion:
        """Create an instance of V1ProjectVersion from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in stage_conditions (list)
        _items = []
        if self.stage_conditions:
            for _item in self.stage_conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['stage_conditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ProjectVersion:
        """Create an instance of V1ProjectVersion from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1ProjectVersion.parse_obj(obj)

        _obj = V1ProjectVersion.parse_obj({
            "uuid": obj.get("uuid"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "tags": obj.get("tags"),
            "owner": obj.get("owner"),
            "project": obj.get("project"),
            "connection": obj.get("connection"),
            "run": obj.get("run"),
            "artifacts": obj.get("artifacts"),
            "meta_info": obj.get("meta_info"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "stage": obj.get("stage"),
            "kind": obj.get("kind"),
            "stage_conditions": [V1StageCondition.from_dict(_item) for _item in obj.get("stage_conditions")] if obj.get("stage_conditions") is not None else None,
            "content": obj.get("content"),
            "readme": obj.get("readme"),
            "state": obj.get("state"),
            "role": obj.get("role")
        })
        return _obj




#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc5
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictStr, conlist
from polyaxon_sdk.models.v1_build import V1Build
from polyaxon_sdk.models.v1_cache import V1Cache
from polyaxon_sdk.models.v1_hook import V1Hook
from polyaxon_sdk.models.v1_io import V1IO
from polyaxon_sdk.models.v1_plugins import V1Plugins
from polyaxon_sdk.models.v1_template import V1Template
from polyaxon_sdk.models.v1_termination import V1Termination

class V1Component(BaseModel):
    """
    V1Component
    """
    version: Optional[StrictFloat] = None
    kind: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    tags: Optional[conlist(StrictStr)] = None
    presets: Optional[conlist(StrictStr)] = None
    queue: Optional[StrictStr] = None
    cache: Optional[V1Cache] = None
    termination: Optional[V1Termination] = None
    plugins: Optional[V1Plugins] = None
    hooks: Optional[conlist(V1Hook)] = None
    inputs: Optional[conlist(V1IO)] = None
    outputs: Optional[conlist(V1IO)] = None
    build: Optional[V1Build] = None
    run: Optional[Dict[str, Any]] = None
    template: Optional[V1Template] = None
    is_approved: Optional[StrictBool] = Field(None, alias="isApproved")
    cost: Optional[StrictFloat] = None
    __properties = ["version", "kind", "name", "description", "tags", "presets", "queue", "cache", "termination", "plugins", "hooks", "inputs", "outputs", "build", "run", "template", "isApproved", "cost"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Component:
        """Create an instance of V1Component from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of cache
        if self.cache:
            _dict['cache'] = self.cache.to_dict()
        # override the default output from pydantic by calling `to_dict()` of termination
        if self.termination:
            _dict['termination'] = self.termination.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plugins
        if self.plugins:
            _dict['plugins'] = self.plugins.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in hooks (list)
        _items = []
        if self.hooks:
            for _item in self.hooks:
                if _item:
                    _items.append(_item.to_dict())
            _dict['hooks'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in inputs (list)
        _items = []
        if self.inputs:
            for _item in self.inputs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['inputs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in outputs (list)
        _items = []
        if self.outputs:
            for _item in self.outputs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['outputs'] = _items
        # override the default output from pydantic by calling `to_dict()` of build
        if self.build:
            _dict['build'] = self.build.to_dict()
        # override the default output from pydantic by calling `to_dict()` of template
        if self.template:
            _dict['template'] = self.template.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Component:
        """Create an instance of V1Component from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Component.parse_obj(obj)

        _obj = V1Component.parse_obj({
            "version": obj.get("version"),
            "kind": obj.get("kind"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "tags": obj.get("tags"),
            "presets": obj.get("presets"),
            "queue": obj.get("queue"),
            "cache": V1Cache.from_dict(obj.get("cache")) if obj.get("cache") is not None else None,
            "termination": V1Termination.from_dict(obj.get("termination")) if obj.get("termination") is not None else None,
            "plugins": V1Plugins.from_dict(obj.get("plugins")) if obj.get("plugins") is not None else None,
            "hooks": [V1Hook.from_dict(_item) for _item in obj.get("hooks")] if obj.get("hooks") is not None else None,
            "inputs": [V1IO.from_dict(_item) for _item in obj.get("inputs")] if obj.get("inputs") is not None else None,
            "outputs": [V1IO.from_dict(_item) for _item in obj.get("outputs")] if obj.get("outputs") is not None else None,
            "build": V1Build.from_dict(obj.get("build")) if obj.get("build") is not None else None,
            "run": obj.get("run"),
            "template": V1Template.from_dict(obj.get("template")) if obj.get("template") is not None else None,
            "is_approved": obj.get("isApproved"),
            "cost": obj.get("cost")
        })
        return _obj




#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc5
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from polyaxon_sdk.models.v1_environment import V1Environment
from polyaxon_sdk.models.v1_init import V1Init

class V1Service(BaseModel):
    """
    V1Service
    """
    kind: Optional[StrictStr] = 'service'
    environment: Optional[V1Environment] = None
    connections: Optional[conlist(StrictStr)] = None
    volumes: Optional[conlist(Dict[str, Any])] = Field(None, description="Volumes is a list of volumes that can be mounted.")
    init: Optional[conlist(V1Init)] = None
    sidecars: Optional[conlist(Dict[str, Any])] = None
    container: Optional[Dict[str, Any]] = None
    ports: Optional[conlist(StrictInt)] = None
    rewrite_path: Optional[StrictBool] = Field(None, alias="rewritePath", description="Rewrite path to remove polyaxon base url(i.e. /v1/services/namespace/owner/project/). Default is false, the service shoud handle a base url.")
    is_external: Optional[StrictBool] = Field(None, alias="isExternal", description="Optional flag to signal to Polyaxon that this service should not go through Polyaxon's auth Default is false, the service will be controlled by Polyaxon's auth.")
    replicas: Optional[StrictInt] = None
    __properties = ["kind", "environment", "connections", "volumes", "init", "sidecars", "container", "ports", "rewritePath", "isExternal", "replicas"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Service:
        """Create an instance of V1Service from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of environment
        if self.environment:
            _dict['environment'] = self.environment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in init (list)
        _items = []
        if self.init:
            for _item in self.init:
                if _item:
                    _items.append(_item.to_dict())
            _dict['init'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Service:
        """Create an instance of V1Service from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Service.parse_obj(obj)

        _obj = V1Service.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'service',
            "environment": V1Environment.from_dict(obj.get("environment")) if obj.get("environment") is not None else None,
            "connections": obj.get("connections"),
            "volumes": obj.get("volumes"),
            "init": [V1Init.from_dict(_item) for _item in obj.get("init")] if obj.get("init") is not None else None,
            "sidecars": obj.get("sidecars"),
            "container": obj.get("container"),
            "ports": obj.get("ports"),
            "rewrite_path": obj.get("rewritePath"),
            "is_external": obj.get("isExternal"),
            "replicas": obj.get("replicas")
        })
        return _obj

